==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/FlowAccessControlConfigurationPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The access control configuration policy.
 * @property allowedCallerIpAddresses The allowed caller IP address ranges.
 * @property openAuthenticationPolicies The authentication policies for workflow.
 */
public data class FlowAccessControlConfigurationPolicyArgs(
    public val allowedCallerIpAddresses: Output<List<IpAddressRangeArgs>>? = null,
    public val openAuthenticationPolicies: Output<OpenAuthenticationAccessPoliciesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs> {
    override fun toJava():
        com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs =
        com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs.builder()
            .allowedCallerIpAddresses(
                allowedCallerIpAddresses?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .openAuthenticationPolicies(
                openAuthenticationPolicies?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [FlowAccessControlConfigurationPolicyArgs].
 */
@PulumiTagMarker
public class FlowAccessControlConfigurationPolicyArgsBuilder internal constructor() {
    private var allowedCallerIpAddresses: Output<List<IpAddressRangeArgs>>? = null

    private var openAuthenticationPolicies: Output<OpenAuthenticationAccessPoliciesArgs>? = null

    /**
     * @param value The allowed caller IP address ranges.
     */
    @JvmName("fnuciepsowtwvsor")
    public suspend fun allowedCallerIpAddresses(`value`: Output<List<IpAddressRangeArgs>>) {
        this.allowedCallerIpAddresses = value
    }

    @JvmName("yyhxvspnrqchqbiu")
    public suspend fun allowedCallerIpAddresses(vararg values: Output<IpAddressRangeArgs>) {
        this.allowedCallerIpAddresses = Output.all(values.asList())
    }

    /**
     * @param values The allowed caller IP address ranges.
     */
    @JvmName("onjhlirhkwmeiuun")
    public suspend fun allowedCallerIpAddresses(values: List<Output<IpAddressRangeArgs>>) {
        this.allowedCallerIpAddresses = Output.all(values)
    }

    /**
     * @param value The authentication policies for workflow.
     */
    @JvmName("ugrqvnkmxgtbpweq")
    public suspend
    fun openAuthenticationPolicies(`value`: Output<OpenAuthenticationAccessPoliciesArgs>) {
        this.openAuthenticationPolicies = value
    }

    /**
     * @param value The allowed caller IP address ranges.
     */
    @JvmName("uiohddayrcdlwexv")
    public suspend fun allowedCallerIpAddresses(`value`: List<IpAddressRangeArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param argument The allowed caller IP address ranges.
     */
    @JvmName("tdtqpgrqvmqneebf")
    public suspend
    fun allowedCallerIpAddresses(argument: List<suspend IpAddressRangeArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            IpAddressRangeArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param argument The allowed caller IP address ranges.
     */
    @JvmName("tvcrwkqxptmsvltd")
    public suspend fun allowedCallerIpAddresses(
        vararg
        argument: suspend IpAddressRangeArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            IpAddressRangeArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param argument The allowed caller IP address ranges.
     */
    @JvmName("mfcqsyheensjxbjr")
    public suspend
    fun allowedCallerIpAddresses(argument: suspend IpAddressRangeArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IpAddressRangeArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param values The allowed caller IP address ranges.
     */
    @JvmName("bwsiknvvncqpmqfl")
    public suspend fun allowedCallerIpAddresses(vararg values: IpAddressRangeArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param value The authentication policies for workflow.
     */
    @JvmName("youyicpgyhqpopsh")
    public suspend fun openAuthenticationPolicies(`value`: OpenAuthenticationAccessPoliciesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.openAuthenticationPolicies = mapped
    }

    /**
     * @param argument The authentication policies for workflow.
     */
    @JvmName("rrxlbkpbhrpamlnq")
    public suspend
    fun openAuthenticationPolicies(argument: suspend OpenAuthenticationAccessPoliciesArgsBuilder.() -> Unit) {
        val toBeMapped = OpenAuthenticationAccessPoliciesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.openAuthenticationPolicies = mapped
    }

    internal fun build(): FlowAccessControlConfigurationPolicyArgs =
        FlowAccessControlConfigurationPolicyArgs(
            allowedCallerIpAddresses = allowedCallerIpAddresses,
            openAuthenticationPolicies = openAuthenticationPolicies,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/FlowAccessControlConfigurationPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The access control configuration policy.
 * @property allowedCallerIpAddresses The allowed caller IP address ranges.
 * @property openAuthenticationPolicies The authentication policies for workflow.
 */
public data class FlowAccessControlConfigurationPolicyArgs(
    public val allowedCallerIpAddresses: Output<List<IpAddressRangeArgs>>? = null,
    public val openAuthenticationPolicies: Output<OpenAuthenticationAccessPoliciesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs> {
    override fun toJava():
        com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs =
        com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs.builder()
            .allowedCallerIpAddresses(
                allowedCallerIpAddresses?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .openAuthenticationPolicies(
                openAuthenticationPolicies?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [FlowAccessControlConfigurationPolicyArgs].
 */
@PulumiTagMarker
public class FlowAccessControlConfigurationPolicyArgsBuilder internal constructor() {
    private var allowedCallerIpAddresses: Output<List<IpAddressRangeArgs>>? = null

    private var openAuthenticationPolicies: Output<OpenAuthenticationAccessPoliciesArgs>? = null

    /**
     * @param value The allowed caller IP address ranges.
     */
    @JvmName("kcriccyvyhxflqbk")
    public suspend fun allowedCallerIpAddresses(`value`: Output<List<IpAddressRangeArgs>>) {
        this.allowedCallerIpAddresses = value
    }

    @JvmName("kyoxthcxpkhbhvgd")
    public suspend fun allowedCallerIpAddresses(vararg values: Output<IpAddressRangeArgs>) {
        this.allowedCallerIpAddresses = Output.all(values.asList())
    }

    /**
     * @param values The allowed caller IP address ranges.
     */
    @JvmName("bqtylhhumbfnkmla")
    public suspend fun allowedCallerIpAddresses(values: List<Output<IpAddressRangeArgs>>) {
        this.allowedCallerIpAddresses = Output.all(values)
    }

    /**
     * @param value The authentication policies for workflow.
     */
    @JvmName("mqmtcwsoxltfrmlr")
    public suspend
    fun openAuthenticationPolicies(`value`: Output<OpenAuthenticationAccessPoliciesArgs>) {
        this.openAuthenticationPolicies = value
    }

    /**
     * @param value The allowed caller IP address ranges.
     */
    @JvmName("woqvhlcpkqqncbna")
    public suspend fun allowedCallerIpAddresses(`value`: List<IpAddressRangeArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param argument The allowed caller IP address ranges.
     */
    @JvmName("brwdgnwtweuedjfd")
    public suspend
    fun allowedCallerIpAddresses(argument: List<suspend IpAddressRangeArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            IpAddressRangeArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param argument The allowed caller IP address ranges.
     */
    @JvmName("piyrqhiptpjqvuft")
    public suspend fun allowedCallerIpAddresses(
        vararg
        argument: suspend IpAddressRangeArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            IpAddressRangeArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param argument The allowed caller IP address ranges.
     */
    @JvmName("tbwfeiowqrdeyjhb")
    public suspend
    fun allowedCallerIpAddresses(argument: suspend IpAddressRangeArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IpAddressRangeArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param values The allowed caller IP address ranges.
     */
    @JvmName("nosqdimgmxdpioff")
    public suspend fun allowedCallerIpAddresses(vararg values: IpAddressRangeArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param value The authentication policies for workflow.
     */
    @JvmName("mfrwrvgyratjknpq")
    public suspend fun openAuthenticationPolicies(`value`: OpenAuthenticationAccessPoliciesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.openAuthenticationPolicies = mapped
    }

    /**
     * @param argument The authentication policies for workflow.
     */
    @JvmName("oatbuxxhtcmwnmtv")
    public suspend
    fun openAuthenticationPolicies(argument: suspend OpenAuthenticationAccessPoliciesArgsBuilder.() -> Unit) {
        val toBeMapped = OpenAuthenticationAccessPoliciesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.openAuthenticationPolicies = mapped
    }

    internal fun build(): FlowAccessControlConfigurationPolicyArgs =
        FlowAccessControlConfigurationPolicyArgs(
            allowedCallerIpAddresses = allowedCallerIpAddresses,
            openAuthenticationPolicies = openAuthenticationPolicies,
        )
}
